@@ -9,7 +9,12 @@
 
 #include <KApplicationTrader>
 #include <KIO/ApplicationLauncherJob>
+#include <kio_version.h>
+#if KIO_VERSION >= QT_VERSION_CHECK(5, 98, 0)
+#include <KIO/JobUiDelegateFactory>
+#else
 #include <KIO/JobUiDelegate>
+#endif
 #include <KLocalizedString>
 #include <KNotificationJobUiDelegate>
 #include <KStandardShortcut>
@@ -88,7 +93,11 @@ void ExportMenu::getKServiceItems()
         const QUrl filename = mExportManager->getAutosaveFilename();
         mExportManager->doSave(filename);
         auto job = new KIO::ApplicationLauncherJob;
+#if KIO_VERSION >= QT_VERSION_CHECK(5, 98, 0)
+        job->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, window()));
+#else
         job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, window()));
+#endif
         job->setUrls({filename});
         job->start();
     });
